@@ -40,7 +40,7 @@ class APIException(WaifuException):
 
 class NoToken(WaifuException):
     """Exception raised when the user try to request the gallery route with no token"""
-    def __init__(self,message=f'You tried to request the gallery route with no token. Please pass your token to HoriAioClient'):
+    def __init__(self,message=f'You tried to request the gallery route with no token. Please pass your token to WaifuAioClient'):
         super().__init__(message)
         self.message=message
         
